﻿------------------------------------------------------------------------------
-- $Id$
------------------------------------------------------------------------------
--                                templates.lua
--
--    Copyright (C) 2012 Deronda
--
--  This program is free software: you can redistribute it and/or modify
--  it under the terms of the GNU Lesser General Public License as published
--  by the Free Software Foundation, either version 3 of the License, or
--  (at your option) any later version.
--
--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.
--
--  You should have received a copy of the GNU Lesser General Public License
--  along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
--  This file is for use with clcInfo by abija.  Some of the code was pulled
--  from existing clcInfo modules and the example module.

--  abija has distributed clcInfo All Rights Reserved.  For more information
--  go to: http://wow.curseforge.com/addons/clctracker/
--
------------------------------------------------------------------------------
-- Author:
--      Deronda (@ Stormreaver)
------------------------------------------------------------------------------
-- Description:
--   Templates for clcInfo_Warrior
--------------------------------------------------------------------------------
-- loader
if not clcInfo then return end
if not clcInfo_Warrior then return end

clcInfo.optionsCMLoaders[#(clcInfo.optionsCMLoaders) + 1] = function()
    -- don't load if class is wrong
    local _, englishClass = UnitClass("player")
    if englishClass ~= clcInfo_Warrior.CLASS then return end
    
    local mod = clcInfo_Options.templates
    local defs = mod.defs
    local format = string.format
    
    local spells = clcInfo_Warrior.spells

    local name
    
    --Icons-----------------------------------------------------------
    -- Generic Warrior -----------------------------------------------
    local basic_cds = clcInfo_Warrior.basic_cds
    -- get the localized names and make cd templates  
    for key, value in pairs(basic_cds) do
        name = GetSpellInfo(value)
        if not name then name = "Unknown Spell" end
        mod:Add("icons", defs.CLASS, name, format([[
        return IconSpell("%s")
        ]], name))
    end 
    
    -- Attack speed debuff
    mod:Add("icons", defs.CLASS, "Attack Speed Debuff", format([[
    return IconMAura("HARMFUL","target","%s","%s","%s","%s","%s","%s","%s","%s")
    ]], spells["Dust Cloud"].name, spells["Tailspin"].name,
    spells["Earth Shock"].name, spells["Frost Fever"].name,
    spells["Infected Wounds"].name, spells["Judgements of the Just"].name,
    spells["Thunder Clap"].name, spells["Waylay"].name))
    
    -- Physical damage debuff
    mod:Add("icons", defs.CLASS, "Physical Damage Debuff", format([[
    return IconMAura("HARMFUL","target","%s","%s","%s","%s","%s","%s","%s")
    ]], spells["Curse of Weakness"].name, spells["Demoralizing Roar"].name,
    spells["Demoralizing Roar - Pet"].name, spells["Demoralizing Screech"].name,
    spells["Demoralizing Shout"].name, spells["Scarlet Fever"].name,
    spells["Vindication"].name))
    
    -- Battle Trance
    name = spells["Battle Trance"].name
    mod:Add("icons", defs.CLASS, name, format([[
    return IconAura("HELPFUL", "player", "%s")
    ]], name))    

    -- Executioner
    name = spells["Executioner"].name
    mod:Add("icons", defs.CLASS, name, format([[
    return IconAura("HELPFUL", "player", "%s")
    ]], name))

    -- Incite
    name = spells["Incite"].name
    mod:Add("icons", defs.CLASS, name, format([[
    return IconAura("HELPFUL", "player", "%s")
    ]], name))

    -- Rend
    name = spells["Rend"].name
    mod:Add("icons", defs.CLASS, TARGET..": "..name, format([[
    return IconAura("HARMFUL|PLAYER", "target", "%s")
    ]], name))
        
    -- Arms--------------------------------------------------
    -- Berserker Rage
    -- Yellow if Deadly Calm is up, will come off cd in 1.5, or rage > 95
    name = spells["Berserker Rage"].name
    mod:Add("icons", defs.CLASS_1, name, format([[
    local visible, texture, start, duration, enable, reversed, count, alpha
           = IconSpell("%s", true, ready)
    local dc_start, dc_duration = GetSpellCooldown(%d)
    local deadly_calm_cd = dc_start + dc_duration - GetTime()
    if not (IconAura("HELPFUL|PLAYER", "player", "%s"))
       and UnitPower("player") <= 95
       and deadly_calm_cd > 1.5 then
        return visible,texture, start, duration, enable, reversed, count, alpha 
    else
        return visible, texture, start, duration, enable, reversed, count,
               alpha, true, 0.8, 0.8, 0.1, 1
    end]], name, spells["Deadly Calm"].id, spells["Deadly Calm"].name)
    )
    
    -- Deadly Calm
    name = spells["Deadly Calm"].name
    mod:Add("icons", defs.CLASS_1, name, format([[
    return IconSpell("%s")
    ]], name))

    -- Heroic Strike
    mod:Add("icons", defs.CLASS_1, spells["Heroic Strike"].name,
            "return IconArmsHeroicStrike()")
            
    -- Inner Rage if Deadly Calm not up and not available for 15
    name = spells["Inner Rage"].name
    mod:Add("icons", defs.CLASS_1, name, format([[
    local visible, texture, start, duration, enable, reversed, count, alpha
            = IconSpell("%s", true, ready)
    local dc_start, dc_duration = GetSpellCooldown(%d)
    local deadly_calm_cd = dc_start + dc_duration - GetTime()
    if not (IconAura("HELPFUL|PLAYER", "player", "%s"))
       and deadly_calm_cd > 15 then
        return visible,texture, start, duration, enable, reversed, count, alpha 
    else
        return visible, texture, start, duration, enable, reversed, count,
               alpha, true, 0.8, 0.8, 0.1, 1
    end]], name, spells["Deadly Calm"].id, spells["Deadly Calm"].name)
    )
    
    -- Lambs to the Slaughter
    name = spells["Slaughter"].name
    mod:Add("icons", defs.CLASS_1, name, format([[
    return IconAura("HELPFUL", "player", "%s")
    ]], name))
    
    -- Recklessness if target health pct > 90 or <= 20
    name = spells["Recklessness"].name
    mod:Add("icons", defs.CLASS_1, name, format([[
    local visible, texture, start, duration, enable, reversed, count, alpha
            = IconSpell("%s", true, ready)
    local target_health_pct = 
                     floor(UnitHealth("target") / UnitHealthMax("target") * 100)
    if target_health_pct > 90 or target_health_pct <= 20 then
        return visible, texture, start, duration, enable, reversed, count,alpha 
    else
        return visible, texture, start, duration, enable, reversed, count,
               alpha, true, 0.8, 0.8, 0.1, 1
    end]], name)
    )
    
    -- Taste For Blood
    name = spells["Taste for Blood"].name
    mod:Add("icons", defs.CLASS_1, name, format([[
    return IconAura("HELPFUL", "player", "%s")
    ]], name))
    
    -- Enrage: Wrecking Crew
    name = spells["Enrage"].name
    mod:Add("icons", defs.CLASS_1, spells["Wrecking Crew"].name..":"..name,
    format([[
    return IconAura("HELPFUL", "player", "%s")
    ]], name))
    
    -- Fury---------------------------------------------------------
  
    -- Protection---------------------------------------------------
    
    --Bars------------------------------------------------------------
    -- Generic Warrior------------------------------------------------
    
    --Executioner
    name = spells["Executioner"].name
    mod:Add("bars", defs.CLASS, name, format([[
    return BarAura("HELPFUL", "player", "%s", nil, true, true)
    ]], name))
    
    --Rage
    name = RAGE
    mod:Add("bars", defs.CLASS, name, format([[
    local rage = UnitPower("player")
    return true, "Interface/ICONS/Ability_Warrior_IntensifyRage", 0,
    UnitPowerMax("player"), rage, nil, "%s", nil, rage
    ]], name))  

    --Rend
    name = spells["Rend"].name
    mod:Add("bars", defs.CLASS, name, format([[
    return BarAura("HARMFUL|PLAYER", "target", "%s", nil, false, true)
    ]], name))

  
    -- Arms--------------------------------------------------
    --Slaughter
    name = spells["Slaughter"].name
    mod:Add("bars", defs.CLASS_1, name, format([[
    return BarAura("HELPFUL", "player", "%s", nil, true, true)
    ]], name))    
    
    --Wrecking Crew: Enrage
    name = spells["Enrage"].name
    mod:Add("bars", defs.CLASS_1, spells["Wrecking Crew"].name..":"..name,
    format([[
    return BarAura("HELPFUL", "player", "%s", nil, false, true)
    ]], name))
    
    -- Fury---------------------------------------------------------
    
    -- Protection---------------------------------------------------
    
    --Multi Icons------------------------------------------------------------
    -- Armor debuff
    mod:Add("micons", defs.CLASS, AURA_TYPE_DEBUFF .. ":" .. ARMOR, format([[
    AddMIcon(nil, IconAura("HARMFUL", "target", "%s"))
    AddMIcon(nil, IconAura("HARMFUL", "target", "%s"))
    AddMIcon(nil, IconAura("HARMFUL", "target", "%s"))
    AddMIcon(nil, IconAura("HARMFUL", "target", "%s"))
    AddMIcon(nil, IconAura("HARMFUL", "target", "%s"))
    ]], spells["Corrosive Spit"].name, spells["Tear Armor"].name,
    spells["Expose Armor"].name, spells["Faerie Fire"].name,
    spells["Sunder Armor"].name))
  
    -- Priorities
    ----------------------------------------------------------------------------
    -- Arms Priorities
    local _, talent_tree_name = GetTalentTabInfo(1)
    mod:Add("icons", defs.CLASS_1, format("%s %s: %s", talent_tree_name,
    COMBATLOG_HIGHLIGHT_ABILITY, REFORGE_CURRENT), "return IconArmsCurrent()")
    mod:Add("icons", defs.CLASS_1, format("%s %s: %s", talent_tree_name,
    COMBATLOG_HIGHLIGHT_ABILITY, NEXT), "IconArmsNext()")
end